.extract_function_name: Extract base function name
Description
This helper function extracts the base name of a function, removing
namespace prefixes.
Usage
.extract_function_name(func)
Value
Character string representing the base name of the function.
Arguments
- func
Function, for example the p- or d- form of a distribution
function.