Internal function to normalise a primary event censored CDF when truncation is applied. The CDF is normalised by dividing by its value at the truncation point D and setting all values beyond D to 1.
.normalise_cdf(result, q, D, pcens_obj, pwindow)Normalised CDF values as a numeric vector
Numeric vector of CDF values to normalise.
Numeric vector of quantiles at which CDF was evaluated.
Numeric truncation point
A primarycensored object as created by new_pcens().
Secondary event window