| .check_truncation_bounds_df | R Documentation |
Internal function to validate that L (lower truncation) is less than D (upper truncation) for all rows in a data frame.
.check_truncation_bounds_df(data, L_col, D_col)
data |
Data frame containing the L and D columns |
L_col |
Name of the column containing L values |
D_col |
Name of the column containing D values |
Invisible NULL if valid, otherwise stops with an error message.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.