| new_pcens | R Documentation |
S3 class for primary event censored distribution computation
new_pcens(pdist, dprimary, dprimary_args, ...)
pdist |
Distribution function (CDF). The package can identify base R
distributions for potential analytical solutions. For non-base R functions,
users can apply |
dprimary |
Function to generate the probability density function
(PDF) of primary event times. This function should take a value |
dprimary_args |
List of additional arguments to be passed to
dprimary. For example, when using |
... |
Additional arguments to be passed to pdist |
An object of class pcens_{pdist_name}_{dprimary_name}. This
contains the primary event distribution, the delay distribution, the
delay distribution arguments, and any additional arguments. It can be
used with the pcens_cdf() function to compute the primary event censored
cdf.
Low level primary event censored distribution objects and methods
pcens_cdf(),
pcens_cdf.default(),
pcens_cdf.pcens_pgamma_dunif(),
pcens_cdf.pcens_plnorm_dunif(),
pcens_cdf.pcens_pweibull_dunif(),
pcens_quantile(),
pcens_quantile.default()
new_pcens(
pdist = pgamma, dprimary = dunif, dprimary_args = list(min = 0, max = 1),
shape = 1, scale = 1
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.