A dataset containing information about the supported primary event distributions in primarycensored. Distributions beyond these are not supported in the stan code but any user functions can be used in the R code.
pcd_primary_distributionsA data.frame with 2 rows and 4 columns:
Distribution name
R density function name
Alternative names/identifiers
Stan distribution ID used in the stan code
Utility functions for working with distributions
add_name_attribute(),
pcd_dist_name(),
pcd_distributions