Learn R Programming

primarycensored (version 1.3.0)

pcd_stan_files: Get Stan files containing specified functions

Description

This function retrieves Stan files from a specified directory, optionally filtering for files that contain specific functions.

Usage

pcd_stan_files(functions = NULL, stan_path = primarycensored::pcd_stan_path())

Value

A character vector of file paths to Stan files.

Arguments

functions

Character vector of function names to search for. If NULL, all Stan files are returned.

stan_path

Character string specifying the path to the directory containing Stan files. Defaults to the Stan path of the primarycensored package.

See Also

Tools for working with package Stan functions pcd_load_stan_functions(), pcd_stan_dist_id(), pcd_stan_functions(), pcd_stan_path()