This function dispatches to either analytical solutions (if available) or
numerical integration via the default method. To see which combinations have
analytical solutions implemented, use methods(pcens_cdf). For example,
pcens_cdf.gamma_unif indicates an analytical solution exists for gamma
delay with uniform primary event distributions.
pcens_cdf(object, q, pwindow, use_numeric = FALSE)Vector of computed primary event censored CDFs
A primarycensored object as created by
new_pcens().
Vector of quantiles
Primary event window
Logical, if TRUE forces use of numeric integration even for distributions with analytical solutions. This is primarily useful for testing purposes or for settings where the analytical solution breaks down.
Low level primary event censored distribution objects and methods
new_pcens(),
pcens_cdf.default(),
pcens_cdf.pcens_pgamma_dunif(),
pcens_cdf.pcens_plnorm_dunif(),
pcens_cdf.pcens_pweibull_dunif(),
pcens_quantile(),
pcens_quantile.default()