This function inverts the primary event censored CDF to compute quantiles.
It uses numerical optimisation via optim to find the value q such that
pcens_cdf() is close to the specified probability. Currently, only the
default numerical inversion method is implemented. Future analytical
solutions may be added.
pcens_quantile(object, p, pwindow, L = 0, D = Inf, use_numeric = FALSE, ...)Vector of primary event censored quantiles.
A primarycensored object as created by new_pcens().
A vector of probabilities at which to compute the quantiles.
Primary event window
Minimum delay (lower truncation point). If greater than 0, the distribution is left-truncated at L. This is useful for modelling generation intervals where day 0 is excluded, particularly when used in renewal models. Defaults to 0 (no left truncation).
Maximum delay (upper truncation point). If finite, the distribution is truncated at D. If set to Inf, no upper truncation is applied. Defaults to Inf.
Logical; if TRUE forces the use of numeric inversion even if an analytical solution is available (not yet implemented).
Additional arguments to be passed to pdist
Low level primary event censored distribution objects and methods
new_pcens(),
pcens_cdf(),
pcens_cdf.default(),
pcens_cdf.pcens_pgamma_dunif(),
pcens_cdf.pcens_plnorm_dunif(),
pcens_cdf.pcens_pweibull_dunif(),
pcens_quantile.default()