check_pdist: Check if a function is a valid cumulative distribution function (CDF)
Description
This function tests whether a given function behaves like a valid CDF by
checking if it's monotonically increasing and bounded between 0 and 1.
Usage
check_pdist(pdist, D, ...)
Value
NULL. The function will stop execution with an error message if
pdist is not a valid CDF.
Arguments
pdist
Distribution function (CDF). The package can identify base R
distributions for potential analytical solutions. For non-base R functions,
users can apply add_name_attribute() to yield properly tagged
functions if they wish to leverage the analytical solutions.
D
Maximum delay (truncation point). If finite, the distribution is
truncated at D. If set to Inf, no truncation is applied. Defaults to Inf.
...
Additional arguments to be passed to pdist
See Also
Distribution checking functions
check_dprimary(),
check_truncation()