S3 class for primary event censored distribution computation
new_pcens(
pdist,
dprimary,
dprimary_args,
pdist_name = lifecycle::deprecated(),
dprimary_name = lifecycle::deprecated(),
...
)An object of class pcens_{pdist_name}_{dprimary_name}. This
contains the primary event distribution, the delay distribution, the
delay distribution arguments, and any additional arguments. It can be
used with the pcens_cdf() function to compute the primary event censored
cdf.
Distribution function (CDF). The package can identify base R
distributions for potential analytical solutions. For non-base R functions,
users can apply add_name_attribute() to yield properly tagged
functions if they wish to leverage the analytical solutions.
Function to generate the probability density function
(PDF) of primary event times. This function should take a value x and a
pwindow parameter, and return a probability density. It should be
normalized to integrate to 1 over [0, pwindow]. Defaults to a uniform
distribution over [0, pwindow]. Users can provide custom functions or use
helper functions like dexpgrowth for an exponential growth distribution.
See pcd_primary_distributions() for examples. The package can identify
base R distributions for potential analytical solutions. For non-base R
functions, users can apply add_name_attribute() to yield properly tagged
functions if they wish to leverage analytical solutions.
List of additional arguments to be passed to
dprimary. For example, when using dexpgrowth, you would
pass list(min = 0, max = pwindow, r = 0.2) to set the minimum, maximum,
and rate parameters
this argument will be
ignored in future versions; use
add_name_attribute() on pdist
instead
this argument will be
ignored in future versions; use
add_name_attribute() on dprimary
instead
Additional arguments to be passed to pdist
Low level primary event censored distribution objects and methods
pcens_cdf(),
pcens_cdf.default(),
pcens_cdf.pcens_pgamma_dunif(),
pcens_cdf.pcens_plnorm_dunif(),
pcens_cdf.pcens_pweibull_dunif(),
pcens_quantile(),
pcens_quantile.default()
new_pcens(
pdist = pgamma, dprimary = dunif, dprimary_args = list(min = 0, max = 1),
shape = 1, scale = 1
)
Run the code above in your browser using DataLab