A character vector of function names that the specified function
depends on, ordered so that dependencies come before functions that use
them. The requested function itself is included as the last element.
Arguments
function_name
Character string, the name of the Stan function.
stan_path
Character string specifying the path to the directory
containing Stan files. Defaults to the Stan path of the primarycensored
package.
See Also
Tools for working with package Stan functions
pcd_load_stan_functions(),
pcd_stan_dist_id(),
pcd_stan_files(),
pcd_stan_functions(),
pcd_stan_path()
# See what primarycensored_lpmf depends onpcd_stan_function_deps("primarycensored_lpmf")
# A function with no dependenciespcd_stan_function_deps("expgrowth_pdf")